@@ -21,7 +21,9 @@ class TransferOutItem(Classified, ElementPresentation):
     def __init__(self, diagram, id=None):
         super().__init__(diagram, id, width=DEFAULT_FTA_MAJOR, height=DEFAULT_FTA_MAJOR)
 
-        self.watch("subject.name").watch("subject.namespace.name")
+        self.watch("subject[UML:NamedElement].name").watch(
+            "subject[UML:NamedElement].namespace.name"
+        )
 
     def update_shapes(self, event=None):
         self.shape = IconBox(
